# Version 1.3.0 - 2025-06-28

* Make `pyproject.toml` configuration section name backwards-compatible

# Version 1.2.0 - 2025-06-03

* Add optional support for parsing SPDX expressions. For now, this is limited to simple OR expressions.

# Version 1.1.0 - 2025-05-26

* Do some more cleanup, including moving the usage docs into a dedicated file.
* Drop `tomli` dependency for Python >= 3.11.

# Version 1.0.0 - 2025-05-16

* First forked version, based upon *pip-licenses* 5.0.
